@@ -32,7 +32,7 @@ def normalize_docvectors(docvectors):
     norms_reshaped = norms.reshape(-1, 1).dot(np.ones((1, docvectors.shape[1])))
     log.info(f'norms_reshaped.shape: {norms_reshaped.shape}')
     if np.any(iszero):
-        log.warning(
+        log.info(
             f'Some doc vectors are zero like this first one: docvectors[{iszero},:] = {docvectors[iszero,:]}')
     norms_reshaped[iszero, :] = 1
     normalized_docvectors = docvectors / norms_reshaped
@@ -66,9 +66,13 @@ def load(domains=FAQ_DOMAINS):
                 try:
                     qa_list = yaml.safe_load(filepointer)
                 except ScannerError as e:
-                    log.error(f"{e}\n    yaml.load unable to read {filepointer.name}")
+                    log.error(f"{e}\n    yaml.safe_load unable to read {filepointer.name}")
                     continue
-            for qa_dict in qa_list:
+
+            for i, qa_dict in enumerate(qa_list):
+                if qa_dict is None:
+                    log.warning(f'Found None instead of dict in FAQ pair {filepointer.name}[{i}].')
+                    qa_dict = {}
                 questions.append(qa_dict.get('Q', qa_dict.get('q', '')))
                 answers.append(qa_dict.get('A', qa_dict.get('a', '')))
                 try:
