@@ -41,7 +41,8 @@ class QualityScore:
         updated_replies = list()
         replies_scores = list(map(list, zip(*metrics_scores)))
         for i, reply in enumerate(replies):
-            updated_replies.append(((reply[0] * sum(replies_scores[i])) / (len(self.metrics) + 1), reply[1]))
+            updated_replies.append(
+                constants.BotReply((reply[0] * sum(replies_scores[i])) / (len(self.metrics) + 1), *list(reply[1:])))
 
         return updated_replies
 
