@@ -10,6 +10,8 @@ git push
 git tag -l | cat
 git tag -a "$1" -m "$2"
 
+rm -rf build
+rm -rf dist
 find qary/data -type f -size +5M -exec rm -f {} \;
 
 python setup.py sdist
